class EnvStore {
    _envConfig;
    _currentKeys;
    constructor() {
        // save envConfig
        this._envConfig = {};
        // current keys used.
        this._currentKeys = [];
    }
    addFunction(specs) {
        this._envConfig = specs.reduce((prev, config) => {
            let mergedConfigKeys = {};
            for (let key in config) {
                if (prev[key]) {
                    if (prev[key].required) {
                        config[key].required = prev[key].required;
                    }
                    if (prev[key].devRequired) {
                        config[key].devRequired = prev[key].devRequired;
                    }
                }
                mergedConfigKeys = {
                    ...prev,
                    ...config,
                    ...mergedConfigKeys,
                };
            }
            return mergedConfigKeys;
        }, this._envConfig);
    }
    set currentKeys(keys) {
        this._currentKeys = keys;
    }
    get envConfig() {
        return this._envConfig;
    }
    get missedKeys() {
        return Object.keys(this._envConfig).filter((key) => !this._currentKeys.includes(key));
    }
    get unUsedKeys() {
        const usedKeys = Object.keys(this._envConfig);
        return this._currentKeys.filter((key) => !usedKeys.includes(key));
    }
    get requiredNodeEnv() {
        return Object.keys(this._envConfig).filter((key) => !!this._envConfig[key].required || this._envConfig[key].required === undefined);
    }
    get devRequiredNodeEnv() {
        return Object.keys(this._envConfig).filter((key) => !!this._envConfig[key].devRequired || this._envConfig[key].devRequired === undefined);
    }
    get optionalNodeEnv() {
        return Object.keys(this._envConfig).filter((key) => this._envConfig[key]?.required && !this._envConfig[key].required);
    }
    printDetails() {
        if (this._currentKeys.length > 0) {
            const missed = this.missedKeys;
            if (missed.length > 0) {
                // Red color = \x1b[31m
                // Back to default = \x1b[0m
                // Yellow = \x1b[33m
                console.warn(`\x1b[31m${'missed keys found in public-config file'}\x1b`);
                console.warn(`\x1b[31m${'['}\x1b[0m`);
                missed.forEach((missedValue) => {
                    console.warn(`\x1b[31m${missedValue}\x1b[0m`);
                });
                console.warn(`\x1b[31m${']'}\x1b[0m`);
            }
            const unUsedKeys = this.unUsedKeys;
            if (unUsedKeys.length > 0) {
                console.info(`\x1b[33m${'unused keys found in public - config file'}\x1b`);
                console.info(`\x1b[33m${'['}\x1b[0m`);
                unUsedKeys.forEach((unUsedKeysValue) => {
                    console.warn(`\x1b[33m${unUsedKeysValue}\x1b[0m`);
                });
                console.info(`\x1b[33m${']'}\x1b[0m`);
            }
            if (missed.length === 0 && unUsedKeys.length === 0) {
                console.log(`\x1b[32m${'Public env is in sync.'}\x1b[0m`);
            }
        }
        const required = this.requiredNodeEnv;
        if (required.length > 0) {
            console.info(`\x1b[33m${'Informational: make sure your envirment has set following'}\x1b[0m`);
            console.info(`\x1b[33m${'['}\x1b[0m`);
            required.forEach((requiredValue) => {
                console.info(`\x1b[33m${requiredValue}\x1b[0m`);
            });
            console.info(`\x1b[33m${']'}\x1b[0m`);
        }
        const optional = this.optionalNodeEnv;
        if (optional.length > 0) {
            console.info(`\x1b[33m${'optional env to set'}\x1b[0m`);
            console.info(`\x1b[33m${'['}\x1b[0m`);
            optional.forEach((optionalValue) => {
                console.info(`\x1b[33m${optionalValue}\x1b[0m`);
            });
            console.info(`\x1b[33m${']'}\x1b[0m`);
        }
    }
}
// Export singleton for use by loader and plugin.
var envStore = new EnvStore();export{envStore as default};//# sourceMappingURL=envStore.mjs.map
